@@ -3,6 +3,7 @@
 
 import logging
 import os
+import json
 from confluent_kafka import Producer, KafkaException, KafkaError
 
 def obtenirConfigurationsProducteurDepuisVariablesEnvironnement():
@@ -72,19 +73,22 @@ def publierMessage(producteur, message, topic, logger=None):
         logging.basicConfig(level=logging.INFO)
         logger = logging.getLogger()
     try:
-        producteur.produce(topic, value=message["value"], key=message["key"], callback=callback_livraison)
+        
+        key = encode_to_bytes(message['key']) if 'key' in message else None
+        value = encode_to_bytes(message['value']) if 'value' in message else None
+        producteur.produce(topic, value=value, key=key, callback=callback_livraison)
         logentry = {}
         logentry['topic'] = topic
-        logentry['key'] = message["key"].decode()
-        logentry['value'] = message["value"].decode()
+        logentry['key'] = key.decode()
+        logentry['value'] = value.decode()
         logentry['message_code'] = "MESSAGE_PUBLIE"
-        log_message = "Message {} publié sur le topic {}".format(message["key"].decode(), topic)
+        log_message = "Message {} publié sur le topic {}".format(key.decode(), topic)
         logger.info(log_message, extra=logentry)
     except BufferError as e:
         logentry = {}
         logentry['topic'] = topic
-        logentry['key'] = message["key"].decode()
-        logentry['value'] = message["value"].decode()
+        logentry['key'] = key.decode()
+        logentry['value'] = value.decode()
         logentry['message_code'] = "PRODUCTEUR_QUEUE_MESSAGE_PLEINE"
         log_message = "La queue de message est pleine. Erreur {}".format(str(e))
         logger.error(log_message, extra=logentry)
@@ -92,8 +96,8 @@ def publierMessage(producteur, message, topic, logger=None):
     except KafkaError as e:
         logentry = {}
         logentry['topic'] = topic
-        logentry['key'] = message["key"].decode()
-        logentry['value'] = message["value"].decode()
+        logentry['key'] = key.decode()
+        logentry['value'] = value.decode()
         logentry['message_code'] = "ERREUR_PRODUCTEUR"
         logentry['error_code'] = e.error_code
         logentry['reason'] = e.reason
@@ -103,8 +107,8 @@ def publierMessage(producteur, message, topic, logger=None):
     except KafkaException as e:
         logentry = {}
         logentry['topic'] = topic
-        logentry['key'] = message["key"].decode()
-        logentry['value'] = message["value"].decode()
+        logentry['key'] = key.decode()
+        logentry['value'] = value.decode()
         logentry['message_code'] = "ERREUR_PRODUCTEUR"
         logentry['error_code'] = e.error_code
         logentry['reason'] = e.reason
@@ -113,4 +117,12 @@ def publierMessage(producteur, message, topic, logger=None):
         return False
         
     producteur.flush()
-    return True
\ No newline at end of file
+    return True
+
+def encode_to_bytes(value=None):
+    if type(value) is str:
+        return value.encode()
+    elif type(value) is dict:
+        return json.dumps(value).encode()
+    else:
+        return value
\ No newline at end of file
